==> d3plus-2.0.1.tgz: package/es/index.js <==
export { version } from "./build/package";
export { Axis, AxisBottom, AxisLeft, AxisRight, AxisTop, date } from "d3plus-axis";
export { colorAdd, colorAssign, colorContrast, colorDefaults, colorLegible, colorLighter, colorSubtract } from "d3plus-color";
export { accessor, assign, attrize, BaseClass, closest, configPrep, constant, elem, findLocale, isObject, merge, parseSides, prefix, RESET, stylize, unique, uuid } from "d3plus-common";
export { dom2canvas, saveElement } from "d3plus-export";
export { format, formatAbbreviate, formatDate, formatDefaultLocale, formatLocale } from "d3plus-format";
export { Geomap } from "d3plus-geomap";
export { Donut, Pack, Pie, Tree, Treemap } from "d3plus-hierarchy";
export { ckmeans, ColorScale, Legend } from "d3plus-legend";
export { Matrix, RadialMatrix } from "d3plus-matrix";
export { Network, Rings, Sankey } from "d3plus-network";
export { AreaPlot, BarChart, BoxWhisker, BumpChart, LinePlot, Plot, Radar, StackedArea } from "d3plus-plot";
export { Priestley } from "d3plus-priestley";
export { Area, Bar, Box, Circle, Image, Line, Path, largestRect, lineIntersection, path2polygon, pointDistance, pointDistanceSquared, pointRotate, polygonInside, polygonRayCast, polygonRotate, segmentBoxContains, segmentsIntersect, shapeEdgePoint, simplify, Rect, Shape, Whisker } from "d3plus-shape";
export { fontExists, rtl, stringify, strip, TextBox, textSplit, textWidth, textWrap, titleCase, trim, trimLeft, trimRight } from "d3plus-text";
export { Timeline } from "d3plus-timeline";
export { Tooltip } from "d3plus-tooltip";
export { addToQueue, dataConcat, dataFold, dataLoad, isData, Viz } from "d3plus-viz";

==> d3plus-2.0.3.tgz: package/es/index.js <==
export { version } from "./build/package";
export { Axis, AxisBottom, AxisLeft, AxisRight, AxisTop, date } from "d3plus-axis";
export { colorAdd, colorAssign, colorContrast, colorDefaults, colorLegible, colorLighter, colorSubtract } from "d3plus-color";
export { accessor, assign, attrize, BaseClass, closest, configPrep, constant, elem, findLocale, isObject, merge, parseSides, prefix, RESET, stylize, unique, uuid } from "d3plus-common";
export { dom2canvas, saveElement } from "d3plus-export";
export { format, formatDate, formatAbbreviate, formatDefaultLocale, formatLocale } from "d3plus-format";
export { Geomap } from "d3plus-geomap";
export { Donut, Pack, Pie, Tree, Treemap } from "d3plus-hierarchy";
export { ckmeans, ColorScale, Legend } from "d3plus-legend";
export { Matrix, RadialMatrix } from "d3plus-matrix";
export { Network, Rings, Sankey } from "d3plus-network";
export { AreaPlot, BarChart, BoxWhisker, BumpChart, LinePlot, Plot, Radar, StackedArea } from "d3plus-plot";
export { Priestley } from "d3plus-priestley";
export { Area, Bar, Box, Circle, Image, Line, Path, largestRect, lineIntersection, path2polygon, pointDistance, pointDistanceSquared, pointRotate, polygonInside, polygonRayCast, polygonRotate, segmentBoxContains, segmentsIntersect, shapeEdgePoint, simplify, Rect, Shape, Whisker } from "d3plus-shape";
export { fontExists, rtl, stringify, strip, TextBox, textSplit, textWidth, textWrap, titleCase, trim, trimLeft, trimRight } from "d3plus-text";
export { Timeline } from "d3plus-timeline";
export { Tooltip } from "d3plus-tooltip";
export { addToQueue, dataConcat, dataFold, dataLoad, isData, Viz } from "d3plus-viz";
